package com.huiju.estateagents.controller;

import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaShareRecord;
import com.huiju.estateagents.service.ITaShareRecordService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>
    * 拼团记录  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-10-18
 */
@RestController
@RequestMapping("/api")
public class TaShareRecordController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaShareRecordController.class);

    @Autowired
    public ITaShareRecordService iTaShareRecordService;


    /**
     * 分页拼团成功列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taShareSuccessRecord",method= RequestMethod.GET)
    public ResponseBean taShareSuccessRecordList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                          @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                          @RequestParam(value ="phone",required = false) String phone,
                                          @RequestParam(value ="status",required = false) Integer status,
                                          HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean = iTaShareRecordService.getSuccessList(pageNum, pageSize, phone, status, getOrgId(request));
            responseBean.addSuccess(responseBean);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareRecordList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 分页拼团进行中和失败列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/admin/taShareFailAndProcessingRecord",method= RequestMethod.GET)
    public ResponseBean taShareFailAndProcessingRecordList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                          @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                          @RequestParam(value ="phone",required = false) String phone,
                                          @RequestParam(value ="status",required = false) Integer status,
                                          HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean = iTaShareRecordService.getFailAndProcessingList(pageNum, pageSize, phone, status, getOrgId(request));
            responseBean.addSuccess(responseBean);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareRecordList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }


    /**
     * 保存拼团中的对象
     * @param taShareRecord 实体对象
     * @return
     */
    @RequestMapping(value="/admin/taShareRecord",method= RequestMethod.POST)
    public ResponseBean taShareRecordAdd(@RequestBody TaShareRecord taShareRecord, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();

        try {
            responseBean = iTaShareRecordService.validateRule(taShareRecord);
            if (responseBean.getCode() != 0){
                return responseBean;
            }
            //0拼团成功 1拼团中 2拼团失败
            taShareRecord.setStatus(1);
            //0未核销 1已核销
            taShareRecord.setVerificationStatus(0);
            taShareRecord.setOrgId(getOrgId(request));
            if (iTaShareRecordService.save(taShareRecord)){
                responseBean.addSuccess(taShareRecord);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareRecordAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taShareRecord/{id}", method= RequestMethod.DELETE)
    public ResponseBean taShareRecordDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaShareRecordService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareRecordDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taShareRecord 实体对象
     * @return
     */
    @RequestMapping(value="/taShareRecord/{id}",method= RequestMethod.PUT)
    public ResponseBean taShareRecordUpdate(@PathVariable Integer id,
                                        @RequestBody TaShareRecord taShareRecord){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaShareRecordService.updateById(taShareRecord)){
                responseBean.addSuccess(taShareRecord);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareRecordUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taShareRecord/{id}",method= RequestMethod.GET)
    public ResponseBean taShareRecordGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaShareRecordService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareRecordDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    @RequestMapping(value="/admin/taShareRecord/verificate/{activityId}",method= RequestMethod.PUT)
    public ResponseBean taShareVerificateRecord(@PathVariable Integer activityId, @RequestParam("verificateCode") String verificateCode){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean = iTaShareRecordService.verifyCode(activityId, verificateCode);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taShareVerificateRecord -=- {}",e.toString());
            responseBean.addError("核销失败");
        }
        return responseBean;
    }
}
