package com.huiju.estateagents.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaPerson;
import com.huiju.estateagents.entity.TaShareActivity;
import com.huiju.estateagents.entity.TaShareRecord;
import com.huiju.estateagents.mapper.TaPersonMapper;
import com.huiju.estateagents.mapper.TaShareActivityMapper;
import com.huiju.estateagents.mapper.TaShareRecordMapper;
import com.huiju.estateagents.po.TaShareRecordPO;
import com.huiju.estateagents.service.ITaShareRecordService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * <p>
 * 拼团记录  服务实现类
 * </p>
 *
 * @author jobob
 * @since 2019-10-18
 */
@Service
public class TaShareRecordServiceImpl extends ServiceImpl<TaShareRecordMapper, TaShareRecord> implements ITaShareRecordService {

    @Autowired
    private TaPersonMapper taPersonMapper;
    @Autowired
    private TaShareActivityMapper activityMapper;
    @Autowired
    private TaShareRecordMapper taShareRecordMapper;

    @Override
    public ResponseBean getSuccessList(Integer pageNum, Integer pageSize, String phone, Integer status, Integer orgId) {
        ResponseBean responseBean = new ResponseBean();
        Page<TaShareRecord> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 1 : pageNum);

        List<TaShareRecord> list = taShareRecordMapper.recordSuccessList(phone, status, orgId);
        responseBean.addSuccess(list);

        return responseBean;
    }

    @Override
    public ResponseBean getFailAndProcessingList(Integer pageNum, Integer pageSize, String phone, Integer status, Integer orgId) {
        ResponseBean responseBean = new ResponseBean();
        Page<TaShareRecord> page = new Page<>();
        page.setSize(pageSize == null ? 10 : pageSize);
        page.setCurrent(pageNum == null ? 1 : pageNum);

        List<TaShareRecordPO> list = taShareRecordMapper.recordFailAndProcessingList(phone, status, orgId);
        responseBean.addSuccess(list);

        return responseBean;
    }

    @Override
    public ResponseBean validateRule(TaShareRecord taShareRecord) {
        ResponseBean responseBean = new ResponseBean();
        try{
            TaPerson taPerson = taPersonMapper.getById(taShareRecord.getPersonId());
            TaShareActivity taShareActivity = activityMapper.selectTaShareActivityById(taShareRecord.getGroupActivityId());

            QueryWrapper<TaShareRecord> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("person_id", taShareRecord.getPersonId());
            TaShareRecord record = taShareRecordMapper.selectOne(queryWrapper);

            if (record != null){
                responseBean.addError("您已经发起拼团，请勿再次发起，加入好友的拼团吧");
                return responseBean;
            }
            if (taPerson.getPoints() == null || taPerson.getPoints() < taShareActivity.getIntegral()){
                responseBean.addError("积分不足");
                return responseBean;
            }
            //扣取积分,更新参团人数
            taPerson.setPoints(taPerson.getPoints() - taShareActivity.getIntegral());
            taPersonMapper.updateById(taPerson);
            activityMapper.updateJoinPeople(taShareRecord.getGroupActivityId());
            responseBean.addSuccess("您已成功发起拼团，赶快邀请好友参团吧");

        }catch (Exception e){
            e.printStackTrace();
            responseBean.addError("发起拼团失败");
        }

        return responseBean;
    }

    @Override
    public ResponseBean verifyCode(Integer activityId, String verifyCode) {
        ResponseBean responseBean = new ResponseBean();
        QueryWrapper<TaShareRecord> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("verification_code", verifyCode);
        TaShareRecord taShareRecord = taShareRecordMapper.selectOne(queryWrapper);
        if (taShareRecord == null){
            responseBean.addError("请输入正确的核销码");
            return responseBean;
        }
        taShareRecord.setGroupActivityId(activityId);
        taShareRecord.setVerificationStatus(1);
        taShareRecordMapper.updateById(taShareRecord);
        responseBean.addSuccess("核销成功");
        return responseBean;
    }
}
